@@ -11,9 +11,6 @@ from typing import List, Optional, Type
 from .helpers import indent_text
 from .sql_section import SqlSection
 from .sql_container import SqlContainer
-from .sql_cols import SqlCols
-from .sql_vals import SqlVals
-from .sql_enum import SqlEnum
 
 
 class SqlQuery:
@@ -60,12 +57,13 @@ class SqlQuery:
 
         if query:
             for section, value in query.items():
-                if isinstance(value, (str, SqlContainer, SqlCols, SqlVals, SqlEnum)):
-                    self[section](value)
-                elif isinstance(value, (list, tuple)):
+                if isinstance(value, (list, tuple)):
                     self[section](*value)
                 elif isinstance(value, dict):
                     self[section](SqlQuery(value)())
+                else:
+                    self[str(section)](str(value))
+
 
     def __bool__(self) -> bool:
         return bool(self.sections)
