@@ -7,9 +7,9 @@ __author__ = 'https://github.com/akvilary'
 
 from typing import Iterable
 
-from . import helpers
-from .sql_enum import SqlEnum
+from .helpers import converters
 from .sql_container import SqlContainer
+from .sql_enum import SqlEnum
 
 
 class SqlVals(SqlEnum):
@@ -35,4 +35,4 @@ class SqlVals(SqlEnum):
 
 def get_values(iterable: Iterable):
     """Get values iterator"""
-    return (helpers.convert_to_sql_repr(x) for x in iterable)
+    return (converters.convert_any_to_sql(x) for x in iterable)
